@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2014-2016 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -345,7 +345,6 @@ static void __attribute__ ((noreturn)) pr_nomem(const char *msg)
 static char *get_pid_cmdline(const pid_t pid)
 {
 	char buffer[BUFFER_SIZE];
-	char *ptr;
 	int fd;
 	ssize_t ret = 0;
 
@@ -374,6 +373,8 @@ static char *get_pid_cmdline(const pid_t pid)
 	if (ret < 1) {
 		strncpy(buffer, "<unknown>", sizeof(buffer));
 	} else {
+		char *ptr;
+
 		for (ptr = buffer; *ptr && (ptr < buffer + ret); ptr++) {
 			if (*ptr == ' ') {
 				*ptr = '\0';
@@ -909,10 +910,10 @@ tidy:
  *	compare file stats, sort by total and if they are
  *	the same, sort by pathname
  */
-int file_stat_cmp(const void *p1, const void *p2)
+static int file_stat_cmp(const void *p1, const void *p2)
 {
-	file_stat_t **fs1 = (file_stat_t **)p1;
-	file_stat_t **fs2 = (file_stat_t **)p2;
+	file_stat_t *const *fs1 = (file_stat_t *const *)p1;
+	file_stat_t *const *fs2 = (file_stat_t *const *)p2;
 
 	if (opt_flags & OPT_SORT_BY_PID) {
 		if ((*fs1)->pid < (*fs2)->pid)
@@ -1112,7 +1113,7 @@ static void pathname_list_free(pathname_t **list)
  *  show_usage()
  *	how to use
  */
-void show_usage(void)
+static void show_usage(void)
 {
 	printf("%s, version %s\n\n", app_name, VERSION);
 	printf("Options are:\n"
@@ -1288,7 +1289,6 @@ int main(int argc, char **argv)
 
 		while(!stop_fnotifystat) {
 			fd_set rfds;
-			int ret;
 			double remaining;
 
 			if (gettimeofday(&tv2, NULL) < 0)
